For module_api sample, use vcpy_kernel.cu to generate ptx file for NV path.

Change-Id: Id0033678834288c4eaa56b12e7d447119be99deb


[ROCm/hip commit: e08f4513c1]
This commit is contained in:
pensun
2016-09-03 21:06:58 -05:00
vanhempi c394892227
commit e9f4f40a45
2 muutettua tiedostoa jossa 8 lisäystä ja 2 poistoa
@@ -21,8 +21,8 @@ endif
ifeq (${HIP_PLATFORM}, nvcc)
vcpy_kernel.compile: vcpy_kernel.cpp
$(HIPCC) --genco vcpy_kernel.cpp -o vcpy_kernel.ptx
vcpy_kernel.compile: vcpy_kernel.cu
$(HIPCC) --genco vcpy_kernel.cu -o vcpy_kernel.ptx
clean:
rm -f *.ptx *.out
@@ -0,0 +1,6 @@
extern "C" __global__ void hello_world(float *a, float *b)
{
int tx = threadIdx.x;
b[tx] = a[tx];
}